@@ -5,7 +5,7 @@ import pprint
 import sys
 import itertools
 
-import jmespath
+import jmespath.exceptions
 
 from .. import __version__
 from .. import __project__
@@ -106,6 +106,26 @@ def jpp_main(argv=None):
             "read from stdin."
         ),
     )
+    parser.add_argument(
+        "-r",
+        "--raw",
+        action="store_false",
+        dest="quoted",
+        default=True,
+        help=(
+            "If the final result is a string, it will be printed without quotes (an alias for unquoted)."
+        ),
+    )
+    parser.add_argument(
+        "-R",
+        "--read-raw",
+        action="store_true",
+        dest="read_raw",
+        default=False,
+        help=(
+            "Read raw string input and box it as JSON strings."
+        ),
+    )
     parser.add_argument(
         "-s",
         "--slurp",
@@ -150,6 +170,10 @@ def jpp_main(argv=None):
     if args.expr_file:
         with open(args.expr_file, "rt") as f:
             expression = f.read()
+        if not expression:
+            raise jmespath.exceptions.EmptyExpressionError()
+    elif not expression:
+        expression = "@"
 
     if args.ast:
         # Only print the AST
@@ -164,23 +188,30 @@ def jpp_main(argv=None):
         f = sys.stdin
 
     accumulator = None
+    stream_iter = None
     eof = False
 
     with f:
-        stream_iter = decode_json_stream(f)
+        if not args.read_raw:
+            stream_iter = decode_json_stream(f)
         while True:
             while True:
                 if args.slurp:
-                    data = list(stream_iter)
-                    if not data:
-                        eof = True
-                        break
+                    if stream_iter is None:
+                        data = f.read()
+                    else:
+                        data = list(stream_iter)
+                elif stream_iter is None:
+                    data = f.readline()
                 else:
                     try:
                         data = next(stream_iter)
                     except StopIteration:
-                        eof = True
-                        break
+                        data = None
+
+                if not data:
+                    eof = True
+                    break
 
                 result = jmespath.search(expression, data)
 
@@ -189,6 +220,8 @@ def jpp_main(argv=None):
                         accumulator = result
                     else:
                         accumulator = merge(accumulator, result)
+                    if args.slurp:
+                        break
                 else:
                     break
 
@@ -201,7 +234,12 @@ def jpp_main(argv=None):
                 result = json.dumps(result, **dump_kwargs)
 
             sys.stdout.write(result)
-            sys.stdout.write("\n")
+
+            if args.quoted or (
+                not args.quoted and isinstance(result, str) and result[-1:] != "\n"
+            ):
+                sys.stdout.write("\n")
+
             if eof or args.accumulate or args.slurp:
                 break
     return 0
